@@ -18,12 +18,12 @@ BEGIN {
     unshift @INC, File::Spec->catdir($cwd, 'lib');
 }
 
-use Test::Unit::Lite 0.10;
+use Test::Unit::Lite 0.11;
 use Test::Assert;
 
 use Exception::Base max_arg_nums => 0, max_arg_len => 200, verbosity => 4;
-use Exception::Warning '%SIG' => 'die', verbosity => 4;
-use Exception::Died '%SIG', verbosity => 4;
 use Exception::Assertion verbosity => 4;
 
+local $SIG{__WARN__} = sub { require Carp; Carp::confess( $_[0] ) };
+
 all_tests;
